#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (C) 2010-2012 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
# 
# PyHoca is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# PyHoca is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.

NSIS_SCRIPT_TEMPLATE = """
;{program_name}.nsi
;

!define VERSION {program_version}

;--------------------------------

; The name of the installer
Name "{program_name}"

; Sets the title bar text (although NSIS seems to append "Installer")
Caption "{program_desc}"

!define py2exeOutputDirectory '{output_dir}'

; The file to write
OutFile "..\\{program_name}_${{VERSION}}_win32-setup.exe"

; The default installation directory
InstallDir $PROGRAMFILES\\{program_name}

; Registry key to check for directory (so if you install again, it will 
; overwrite the old one automatically)
InstallDirRegKey HKLM "Software\\{program_name}" "Install_Dir"

; Request application privileges for Windows Vista
RequestExecutionLevel admin

;--------------------------------

; Installer Language Configuration

!include LogicLib.nsh

var LC_MESSAGES

; i18n strings
var REQUIRED
var DESKTOP_LINKS
var STARTMENU_LINKS
var WITHOUT_PULSEAUDIO
var GSPRINT

; First is default
LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\English.nlf"
LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\Dutch.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\French.nlf"
LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\German.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\Korean.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\Russian.nlf"
LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\Spanish.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\Swedish.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\TradChinese.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\SimpChinese.nlf"
;LoadLanguageFile "${{NSISDIR}}\\Contrib\\Language files\\Slovak.nlf"

; License data
; Not exactly translated, but it shows what's needed
LicenseLangString myLicenseData ${{LANG_ENGLISH}} "LICENSE.txt"
LicenseLangString myLicenseData ${{LANG_DUTCH}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_FRENCH}} "LICENSE.txt"
LicenseLangString myLicenseData ${{LANG_GERMAN}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_KOREAN}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_RUSSIAN}} "LICENSE.txt"
LicenseLangString myLicenseData ${{LANG_SPANISH}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_SWEDISH}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_TRADCHINESE}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_SIMPCHINESE}} "LICENSE.txt"
;LicenseLangString myLicenseData ${{LANG_SLOVAK}} "LICENSE.txt"

LicenseData $(myLicenseData)

; Set name using the normal interface (Name command)
LangString Name ${{LANG_ENGLISH}} "English"
LangString Name ${{LANG_DUTCH}} "Dutch"
;LangString Name ${{LANG_FRENCH}} "French"
LangString Name ${{LANG_GERMAN}} "German"
;LangString Name ${{LANG_KOREAN}} "Korean"
;LangString Name ${{LANG_RUSSIAN}} "Russian"
LangString Name ${{LANG_SPANISH}} "Spanish"
;LangString Name ${{LANG_SWEDISH}} "Swedish"
;LangString Name ${{LANG_TRADCHINESE}} "Traditional Chinese"
;LangString Name ${{LANG_SIMPCHINESE}} "Simplified Chinese"
;LangString Name ${{LANG_SLOVAK}} "Slovak"

Function .onInit

        ;Language selection dialog

        Push ""
        Push ${{LANG_ENGLISH}}
        Push English
        Push ${{LANG_DUTCH}}
        Push Dutch
;       Push ${{LANG_FRENCH}}
;       Push French
        Push ${{LANG_GERMAN}}
        Push German
;       Push ${{LANG_KOREAN}}
;       Push Korean
;       Push ${{LANG_RUSSIAN}}
;       Push Russian
        Push ${{LANG_SPANISH}}
        Push Spanish
;       Push ${{LANG_SWEDISH}}
;       Push Swedish
;       Push ${{LANG_TRADCHINESE}}
;       Push "Traditional Chinese"
;       Push ${{LANG_SIMPCHINESE}}
;       Push "Simplified Chinese"
;       Push ${{LANG_SLOVAK}}
;       Push Slovak
        Push A ; A means auto count languages
               ; for the auto count to work the first empty push (Push "") must remain
        LangDLL::LangDialog "Installer Language" "Please select the language of the installer"

        Pop $LANGUAGE

        ${{Switch}} $LANGUAGE
          ${{Case}} 1031
            StrCpy $LC_MESSAGES "de"
            !include "nsis_include\\de.nsi"
            ${{Break}}
          ${{Case}} 1033
            StrCpy $LC_MESSAGES "en"
            !include "nsis_include\\en.nsi"
            ${{Break}}
          ${{Case}} 1043
            StrCpy $LC_MESSAGES "nl"
            !include "nsis_include\\nl.nsi"
            ${{Break}}
          ${{Case}} 1034
            StrCpy $LC_MESSAGES "es"
            !include "nsis_include\\es.nsi"
            ${{Break}}
        ${{EndSwitch}}

        StrCmp $LANGUAGE "cancel" 0 +2
            Abort

FunctionEnd

;--------------------------------

; Pages
Page license
Page components
Page directory
Page instfiles

UninstPage uninstConfirm
UninstPage instfiles

;--------------------------------

; The stuff to install
Section "{program_name} ($REQUIRED)"

  SectionIn RO
  ; Set output path to the installation directory.
  SetOutPath "$INSTDIR"
  File /r /x .svn /x .git "${{py2exeOutputDirectory}}\\*.*"

  ; Write the installation path into the registry
  WriteRegStr HKLM SOFTWARE\\{program_name} "Install_Dir" "$INSTDIR"

  ; Write the uninstall keys for Windows
  WriteRegStr HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "DisplayName" "{program_name}"
  WriteRegStr HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "UninstallString" '"$INSTDIR\\uninstall.exe"'
  WriteRegDWORD HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "NoModify" 1
  WriteRegDWORD HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}" "NoRepair" 1
  WriteUninstaller "uninstall.exe"

SectionEnd

; Optional section (can be disabled by the user)
Section "$STARTMENU_LINKS"

  CreateDirectory "$SMPROGRAMS\\{program_name}"
  CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name}.lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
  CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name} ($WITHOUT_PULSEAUDIO).lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
  CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name} (debug).lnk" "$INSTDIR\\{program_name}.exe" "--debug --libdebug --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
  CreateShortCut "$SMPROGRAMS\\{program_name}\\{program_name} ($WITHOUT_PULSEAUDIO, debug).lnk" "$INSTDIR\\{program_name}.exe" "--debug --libdebug --start-xserver --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0
  CreateShortCut "$SMPROGRAMS\\{program_name}\\X2go Website.lnk" "http://www.x2go.org" "" "$INSTDIR\\icons\\pyhoca_x2go-logo-ubuntu.ico" 0
  CreateShortCut "$SMPROGRAMS\\{program_name}\\Uninstall.lnk" "$INSTDIR\\uninstall.exe" "" "$INSTDIR\\uninstall.exe" 0

SectionEnd

; Optional section (can be disabled by the user)
Section "$DESKTOP_LINKS"

  CreateShortCut "$DESKTOP\\{program_name}.lnk" "$INSTDIR\\{program_name}.exe" "--quiet --start-xserver --start-pulseaudio --lang $LC_MESSAGES" "$INSTDIR\\icons\\{program_name}.ico" 0

SectionEnd

;--------------------------------

; Uninstaller

Section "Uninstall"

  ; Remove registry keys
  DeleteRegKey HKLM "Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\{program_name}"
  DeleteRegKey HKLM SOFTWARE\\{program_name}

  ; Remove files and uninstaller
  Delete $INSTDIR\\uninstall.exe

  ; Remove shortcuts, if any
  Delete "$SMPROGRAMS\\{program_name}\\*.*"
  Delete "$DESKTOP\\{program_name}.lnk"

  ; Remove directories used
  RMDir "$SMPROGRAMS\\{program_name}"
  RMDir /r /REBOOTOK $INSTDIR

SectionEnd
"""
